/* $Id: Filter-stream-test.cpp,v 1.3 2003/03/12 22:57:39 lergnom Exp $ -*- C++ -*-
 * 
 * libbpfl - Bayesian Probability Filtering Library
 * Copyright (C) 2003 Anthony Ventimiglia
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#include "bpfHash.h"
#include "bpfFilter.h"
#include "bpfBucket.h"

#include <iostream>
#include <string>
#include <fstream>

struct Hash : public bpf::Hash_base<std::string>
{
    size_t operator() ( const std::string& word )
	{
	    using std::string;
	    size_t hval = 0;
	    for ( string::const_iterator i = word.begin(); i != word.end(); 
		  ++i )
		hval = (hval << 1 ) ^ *i;
	    return hval;
	}
};

int main ()
{
    using namespace std;
    
    typedef bpf::Bucket<string, Hash> strBucket;

    strBucket *a = new strBucket ( "Bucket-A" );
    strBucket *b = new strBucket ( "Bucket-B" );
    strBucket *c = new strBucket ( "Bucket-C" );

    a->load ( "Bucket-a" );
    b->load ( "Bucket-b" );
    c->load ( "Bucket-c" );

    typedef bpf::Filter<string, Hash> strFilter;
    strFilter f;
    f.add_bucket ( a );
    f.add_bucket ( b );
    f.add_bucket ( c );

    ifstream tstr ( "Words" );
    strFilter::score_info* info = f.score_stream ( tstr );

    cout << "Results from strFilter::score_stream():\n"
	 << "Tokens read:\n";
    for ( size_t i = 0; i < info->tokens.size(); ++i )
	cout << info->tokens[i] << endl;
    

    cout << "\nToken Scores:\n";
    vector<string> names = f.get_bucket_names ();
    for ( size_t i = 0; i < names.size(); ++i )
	cout << names[i] << "\t";
    cout << "token\n------------------------------------------\n";

    cout.setf ( ios_base::fixed );
    cout.precision ( 5 );
    for ( size_t token = 0; token < info->tokens.size(); ++token ) {
	for ( size_t bucket = 0; bucket < info->scores.size(); ++bucket )
	    cout << info->scores[bucket][token] << "\t\t";
	cout << info->tokens[token] << endl;
    }

    cout << "Bucket scores:\n";
    for ( size_t b = 0; b < info->bucket_scores.size(); ++b )
	cout << '\t' << names[b] << " : " << info->bucket_scores[b] << endl;
    
    delete info;
    delete a;
    delete b;
    return 0;
}
