/* $Id: Filter-test.cpp,v 1.7 2003/03/12 20:38:38 lergnom Exp $ -*- C++ -*-
 * 
 * libbpfl - Bayesian Probability Filtering Library
 * Copyright (C) 2003 Anthony Ventimiglia
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#include "bpfHash.h"
#include "bpfFilter.h"
#include "bpfBucket.h"

#include <iostream>
#include <string>
#include <fstream>

struct Hash : public bpf::Hash_base<std::string>
{
    size_t operator() ( const std::string& word )
	{
	    using std::string;
	    size_t hval = 0;
	    for ( string::const_iterator i = word.begin(); i != word.end(); 
		  ++i )
		hval = (hval << 1 ) ^ *i;
	    return hval;
	}
};
    
int main ()
{
    using namespace std;

    typedef bpf::Bucket<string, Hash> strBucket;
    
    strBucket *a = new strBucket( "Bucket-a" );
    strBucket *b = new strBucket( "Bucket-b" );
    
    a->load ( "Bucket-a" );
    b->load ( "Bucket-b" );

    bpf::Filter<string, Hash> f;
    f.add_bucket ( a );
    f.add_bucket ( b );

    cout << "from bpf::Filter<string, Hash>::score_token ( string )\n";
    vector<string> names = f.get_bucket_names ();
    for ( size_t i = 0; i < names.size(); ++i )
	cout << names[i] << "\t";
    cout << "word\n";
    
    ifstream wfile ( "Words" ); 
    cout.setf( ios_base::fixed );
    cout.precision ( 5 );
    while ( wfile ) {
	typedef vector<double> DVec;
	DVec s;
	string tok;
	wfile >> tok;
	if ( ! wfile ) break;
	s = f.score_token ( tok );
	for ( DVec::iterator si = s.begin(); si != s.end(); ++si )
	    cout << *si << "\t\t";
	cout << tok << endl;
    }
    wfile.close();
    
    delete a;
    delete b;

    
    return 0;
}
    
    
